@@ -6,7 +6,6 @@ use WWW::Sitebase -Base;
 use Carp;
 use WWW::Mechanize;
 use File::Spec::Functions;
-use Term::ReadKey; # For password prompt
 
 =head1 NAME
 
@@ -14,11 +13,11 @@ WWW::Sitebase::Navigator - Base class for modules that navigate web sites
 
 =head1 VERSION
 
-Version 0.11
+Version 0.03
 
 =cut
 
-our $VERSION = '0.11';
+our $VERSION = '0.03';
 
 =head1 SYNOPSIS
 
@@ -79,12 +78,6 @@ version of an overridden method.
             # periodically spew error messages that go away when tried again.
     };
 
-IMPORTANT:  If the site your module navigates uses ANY SSL, you'll
-need to add "Crypt::SSLEay" or "IO::Socket::SSL" to your list of prerequisite
-modules.  Otherwise your methods will die if they hit an SSL-encrypted page.
-WWW::Sitebase::Navigator doesn't require this for you to prevent unnecessary
-overhead for sites that don't need it.
-
 =cut
 
 # Where should we store files? (cookies, cache dir). We use, and untaint,
@@ -114,45 +107,42 @@ These are parsed by Params::Validate.  In breif, setting an
 option to "0" means it's optional, "1" means it's required.
 See Params::Validate for more info.
 
-    sub default_options {
-        $self->{default_options}={
-            account_name => 0,
-            password => 0,
-            cache_dir => 0,  # Default set by site_info field method
-            cache_file => 0, # Default set by field method below
-            auto_login => 0, # Default set by field method below
-            human => 0,      # Default set by field method below
-            config_file => 0
-        };
+ sub default_options {
+     super;
+     $self->{default_options}->{my_option1} = 0;
+     $self->{default_options}->{my_option2} = 0;
 
-        return $self->{default_options};
-    }
+     # Make account_name mandatory
+     $self->{default_options}->{account_name} = 1;
+ }
 
-    # So to add a "questions" option that's mandatory:
+ # To completely change the options, do this instead:
+ const default_options => {
+    account_name => 1,  # Make account and password mandatory
+    password => 1,
+ }
 
-    sub default_options {
-        super;
-        $self->{default_options}->{questions}=1;
-        return $self->{default_options};
-    }
+In the second example above, the user would be required to provide
+an account_name and password, but would not be able to specify
+any other options to the "new" method, although they'll still
+be settable via the accessor methods discussed below.
+
+Note that the second example is dangerous, since there are certain
+fields required by WWW::Sitebase::Navigator (i.e. the ones in
+default_options), so you'll probably want those, and you'll probably
+also want to allow any new options added in the future.
 
 =cut
 
 # Options they can pass via hash or hashref.
-sub default_options {
-    $self->{default_options}={
-        account_name => 0,
-        password => 0,
-        cache_dir => 0,  # Default set by site_info field method
-        cache_file => 0, # Default set by field method below
-        auto_login => 0, # Default set by field method below
-        human => 0,      # Default set by field method below
-        config_file => 0,
-        use_defaults => 0
-    };
-    
-    return $self->{default_options};
-}
+const default_options => {
+    account_name => 0,
+    password => 0,
+    cache_dir => 0,  # Default set by site_info field method
+    cache_file => 0, # Default set by field method below
+    auto_login => 0, # Default set by field method below
+    human => 0,      # Default set by field method below
+};
 
 =head2 positional_parameters
 
@@ -182,7 +172,6 @@ field 'password';
 field cache_file => 'login_cache';
 field auto_login => 0;
 field human => 1;
-field use_defaults => 0;
 
 stub 'site_info';
 
@@ -265,7 +254,7 @@ not be used.
 Really only useful as an option passed to the "new" method when
 creating a new object.
 
- # Create a new object and prompt the user to log in.
+ # Don't log in, just create a new object
  my $site = new WWW::MySite( auto_login => 1 );
 
 =cut
@@ -280,12 +269,6 @@ trying to use multiple accounts to spam users who don't
 want to hear what you have to say, you should turn this off
 because it'll make your spamming go faster.
 
-=head2 use_defaults
-
-When set to a true value, cached username and password will be used, and
-the user will only be prompted for a username and password if one or both
-aren't already stored.
-
 =cut
 
 
@@ -407,11 +390,11 @@ sub site_login {
     return undef if $self->error;
 
     # Load the home page.
-#     $self->_go_home;
+    $self->_go_home;
 
     # Verify we're logged in
     if ( ( ! $verify_re ) ||
-         ( $self->current_page->decoded_content =~ /$verify_re/si )
+         ( $self->current_page->content =~ /$verify_re/si )
        ) {
         $self->logged_in( 1 );
     } else {
@@ -533,7 +516,7 @@ sub _check_login {
     # Check for the "proper" error response, or just look for the
     # error message on the page.
     $re = $self->site_info->{'not_logged_in_re'};
-    if ( ( $res->is_error == 403 ) || ( $res->decoded_content =~ /$re/is ) ) {
+    if ( ( $res->is_error == 403 ) || ( $res->content =~ /$re/is ) ) {
         if ( $res->is_error ) {
             warn "Error: " . $res->is_error . "\n"
         } else {
@@ -588,10 +571,7 @@ sub _new_mech {
     # Set up our web browser (WWW::Mechanize object)
     $self->mech( new WWW::Mechanize(
                  onerror => undef,
-                 # We'll say we're Safari running on MacOS 10.9.1
-                 agent => 'Mozilla/5.0 (Macintosh; Intel Mac OS X 10_9_1)'
-                    . ' AppleWebKit/537.73.11 (KHTML, like Gecko) Version/7.0.1'
-                    . ' Safari/537.73.11',
+                 agent => 'Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1)',
                  stack_depth => 1,
                  quiet => 1,
                ) );
@@ -609,7 +589,7 @@ sub _new_mech {
 sub _get_acct {
 
     # Initialize
-    my $prefs = {};
+    my %prefs = ();
     my $ref = "";
     my ( $pref, $value, $res );
     my $cache_filepath = catfile( $self->cache_dir, $self->cache_file);
@@ -619,67 +599,39 @@ sub _get_acct {
         while (<PREFS>) {
             chomp;
             ( $pref, $value ) = split( ":" );
-            $prefs->{"$pref"} = $value;
+            $prefs{"$pref"} = $value;
         }
         
         close PREFS;
     }
 
-    # If we have a username and password, and they asked us to use the
-    # cached defaults, then skip the login prompts.  Otherwise, prompt
-    # the user for login info.
-    unless ( $self->use_defaults && $prefs->{'email'} && $prefs->{'password'} ) {
-        $prefs = $self->_prompt_for_login( $prefs );
-    }
-    
-    # Store the account info.
-    $self->{account_name}=$prefs->{"email"};
-    $self->{password}=$prefs->{"password"};
-}
-
-# _prompt_for_login( { email => $email, password => $password } )
-#
-# Given an optional email and password, prompt the user, displaying the
-# existing email and password as defaults (well, passwords are displayed as
-# "*****").  Returns the email and password entered, or defaulted to,
-# by the user.
-#
-sub _prompt_for_login {
-    my ( $prefs ) = @_;
-
     # Prompt them for current values
-    unless ( defined $prefs->{"email"} ) { $prefs->{"email"} = "" }
-    print "Email [" . $prefs->{"email"} . "]: ";
-    my $res = ReadLine 0; chomp $res;
+    unless ( defined $prefs{"email"} ) { $prefs{"email"} = "" }
+    print "Email [" . $prefs{"email"} . "]: ";
+    $res = <STDIN>; chomp $res;
     if ( $res ) {
-        $prefs->{"email"} = $res;
+        $prefs{"email"} = $res;
     }
 
-    unless ( defined $prefs->{"password"} ) { $prefs->{"password"} = "" }
-    my $password_indicator = $prefs->{'password'} ? '*****' : '';
-    print "Password [". $password_indicator . "]: ";
-    ReadMode 'noecho'; # From Term::ReadKey.  Make password not echo.
-    $res = ReadLine 0;
-    chomp $res;
-    ReadMode 'normal';
-    print "\n"; # Because ReadLine won't output a new line when they hit return
+    unless ( defined $prefs{"password"} ) { $prefs{"password"} = "" }
+    print "Password [". $prefs{"password"} . "]: ";
+    $res = <STDIN>; chomp $res;
     if ( $res ) {
-        $prefs->{"password"} = $res;
+        $prefs{"password"} = $res;
     }
 
     # Make the cache directory if it doesn't exist.
     $self->make_cache_dir;
 
-    # Store the new values.  We clobber the file, set it r/w by the user,
-    # *then* write.
-    my $cache_filepath = catfile( $self->cache_dir, $self->cache_file);
+    # Store the new values.
     open ( PREFS, ">", $cache_filepath ) or croak $!;
-    chmod 0600, $cache_filepath;
-    print PREFS "email:" . $prefs->{"email"} . "\n" .
-        "password:" . $prefs->{"password"} . "\n";
-    close PREFS || croak "Error closing file when writing username/password: $!";
-
-    return $prefs;
+    print PREFS "email:" . $prefs{"email"} . "\n" .
+        "password:" . $prefs{"password"} . "\n";
+    close PREFS;
+    
+    # Store the account info.
+    $self->{account_name}=$prefs{"email"};
+    $self->{password}=$prefs{"password"};
 }
 
 =head2 logout
@@ -718,11 +670,11 @@ sub ____CHECK_STATUS____ {}
 =head2 logged_in
 
 Returns true if login was successful. When you call the new method
-of WWW::Sitebase::Navigator, the class logs in using the username and password
-you provided (or that it prompted for).  It then retreives your "home"
-page (the one you see when you click the "Home" button that's set up in your
-site_info field), and checks it against an RE.  If the page matches the RE,
-logged_in is set to a true value. Otherwise it's set to a false value.
+of WWW::Bebo, the class logs in using the username and password you
+provided (or that it prompted for).  It then retreives your "home"
+page (the one you see when you click the "Home" button on bebo.com,
+and checks it against an RE.  If the page matches the RE, logged_in is
+set to a true value. Otherwise it's set to a false value.
 
  Notes:
  - This method is only set on login. If you're logged out somehow,
@@ -732,15 +684,14 @@ logged_in is set to a true value. Otherwise it's set to a false value.
    it, but that would be stupid, and it might not work later
    anyway, so don't.
 
- Examples, pretending we have a subclass named WWW::Bebo to navigate a site
- named bebo.com:
+ Examples:
 
  my $bebo = new WWW::Bebo;
  unless ( $site->logged_in ) {
     die "Login failed\n";
  }
  
- # This will log you in, looping forever until it succeeds.
+ # This will try forever to log in
  my $bebo;
 
  do {
@@ -770,7 +721,7 @@ field 'error' => 0;
 =head2 current_page
 
 Returns a reference to an HTTP::Response object that contains the last page
-retreived by the WWW::Sitebase::Navigator object. All methods (i.e. get_page, post_comment,
+retreived by the WWW::Bebo object. All methods (i.e. get_page, post_comment,
 get_profile, etc) set this value.
 
 EXAMPLE
@@ -780,7 +731,7 @@ The following will print the content of the user's profile page:
     use WWW::Bebo;
     my $bebo = new WWW::Bebo;
     
-    print $site->current_page->decoded_content;
+    print $site->current_page->content;
 
 =cut
 
@@ -794,7 +745,7 @@ sub current_page {
 
 The internal WWW::Mechanize object.  Use at your own risk: I don't
 promose this method will stay here or work the same in the future.
-The internal methods used to access sites are subject to change at
+The internal methods used to access Bebo are subject to change at
 any time, including using something different than WWW::Mechanize.
 
 =cut
@@ -827,9 +778,9 @@ EXAMPLE
     # The following displays the HTML source of MySpace.com's home
     # page, verifying that there is evidence of a login form on the
     # retreived page.
-    my $res=get_page( "http://www.myspace.com/", re => 'E-Mail:.*?Password:' );
+    my $res=get_page( "http://www.myspace.com/", 'E-Mail:.*?Password:' );
     
-    print $res->decoded_content;
+    print $res->content;
 
 =cut
 
@@ -1013,13 +964,13 @@ sub _page_ok {
     elsif ( $res->is_success ) {
 
         # Page loaded, but make sure it isn't an error page.
-        $page = $res->decoded_content; # Get the content
+        $page = $res->content; # Get the content
         $page =~ s/[ \t\n\r]+/ /g; # Strip whitespace
 
         # If they gave us a RE with which to verify the page, look for it.
         if ( $regexp ) {
             # Page must match the regexp
-            unless ( $page =~ /$regexp/ism ) {
+            unless ( $page =~ /$regexp/i ) {
                 $page_ok = 0;
                 $self->error("Page doesn't match verification pattern.");
 #                warn "Page doesn't match verification pattern.\n";
@@ -1030,7 +981,7 @@ sub _page_ok {
             if ( defined $self->site_info->{'error_regexs'} ) {
                 $errors = $self->site_info->{'error_regexs'};
                 foreach my $error_regex ( @{$errors} ) {
-                    if ( $page =~ /$error_regex/ism ) {
+                    if ( $page =~ /$error_regex/i ) {
                         $page_ok = 0;
                         $self->error( "Got error page." );
 #                        warn "Got error page.\n";
@@ -1092,8 +1043,8 @@ the current page ( $site->current_page ) is used.
 
 "form_no" is used to numerically identify the form on the page. It's a
 simple counter starting from 1.  If there are 3 forms on the page and
-you want to fill in and submit the second form, set "form_no => 2".
-For the first form, use "form_no => 1".
+you want to fill in and submit the second form, set "form_no => 1".
+For the first form, use "form_no => 0".
 
 "form_name" is used to indentify the form by name.  In actuality,
 submit_form simply uses "form_name" to iterate through the forms
@@ -1127,7 +1078,8 @@ until it matches. See get_page for more info.
 
 "re2" is an optional RE that will me used to make sure that the
 post was successful. USE THIS CAREFULLY! If your RE breaks, you could
-end up repeatedly posting a form.
+end up repeatedly posting a form. This is used by post_comemnts to make
+sure that the Verify Comment page is actually shown.
 
 "action" is the post action for the form, as in:
 
@@ -1138,7 +1090,7 @@ form actions with Javascript then post them without clicking form buttons.
 
 EXAMPLE
 
-This is how WWW::Myspace's post_comment method posted a comment:
+This is how post_comment actually posts the comment:
 
     # Submit the comment to $friend_id's page
     $self->submit_form( "${VIEW_COMMENT_FORM}${friend_id}", 1, "submit",
@@ -1199,22 +1151,22 @@ sub submit_form {
         }
     
         $f = $forms[ $options{'form_no'} ];
-    }
     
-    # Set the action if they gave us one
-    if ( $options{'action'} ) { $f->action( $options{'action'} ) }
-    
-    # Loop through the fields in the form and set them.
-    foreach my $field ( keys %{ $options{'fields_ref'} } ) {
-        # If the field "exists" on the form, just fill it in,
-        # otherwise, add it as a hidden field.
-        if ( $f->find_input( $field ) ) {
-            if ( $f->find_input( $field )->readonly ) {
-                $f->find_input( $field )->readonly(0)
+        # Set the action if they gave us one
+        if ( $options{'action'} ) { $f->action( $options{'action'} ) }
+        
+        # Loop through the fields in the form and set them.
+        foreach my $field ( keys %{ $options{'fields_ref'} } ) {
+            # If the field "exists" on the form, just fill it in,
+            # otherwise, add it as a hidden field.
+            if ( $f->find_input( $field ) ) {
+                if ( $f->find_input( $field )->readonly ) {
+                    $f->find_input( $field )->readonly(0)
+                }
+                $f->param( $field, $options{'fields_ref'}->{ $field } );
+            } else {
+                $f = $self->_add_to_form( $f, $field, $options{'fields_ref'}->{ $field } );
             }
-            $f->param( $field, $options{'fields_ref'}->{ $field } );
-        } else {
-            $f = $self->_add_to_form( $f, $field, $options{'fields_ref'}->{ $field } );
         }
     }
 
@@ -1232,7 +1184,7 @@ sub submit_form {
             if ( $options{'button'} ) {
                 $res = $self->mech->request( $f->click( $options{'button'} ) );
             } elsif ( $options{'no_click'} ) {
-                # We use make_request because some sites like submitting forms
+                # We use make_request because Myspace likes submitting forms
                 # that have buttons by using Javascript. make_request submits
                 # the form without clicking anything, whereas "click" clicks
                 # the first button, which can break things.
