@@ -1,4 +1,4 @@
-# $Id: Poster.pm,v 1.1 2013/12/22 05:33:16 grant Exp $
+# $Id: Poster.pm,v 1.4 2007/07/25 19:19:04 grant Exp $
 
 package WWW::Sitebase::Poster;
 
@@ -16,11 +16,11 @@ WWW::Sitebase::Poster - Base class for web site posting routines
 
 =head1 VERSION
 
-Version 0.4
+Version 0.3
 
 =cut
 
-our $VERSION = '0.4';
+our $VERSION = '0.3';
 
 =head1 SYNOPSIS
 
@@ -138,55 +138,18 @@ using.
 
 =cut
 
-=head2 default_options
+const default_options => {
 
-Override this method to allow additional options to be passed to
-"new".  You should also provide accessor methods for them.
-These are parsed by Params::Validate.  In breif, setting an
-option to "0" means it's optional, "1" means it's required.
-See Params::Validate for more info. It looks like this:
+    friend_ids          => 0,
+    cache_file          => 0,
+    html                => 0,
+    browser             => 0,
+    exclude_my_friends  => { default => 0 },
+    interactive         => { default => 1 },
+    noisy               => { default => 1 },
+    max_count           => { default => 0 },
 
-    sub default_options {
-    
-        $self->{default_options} = {
-            friend_ids          => 0,
-            cache_file          => 0,
-            html                => 0,
-            browser             => 0,
-            exclude_my_friends  => { default => 0 },
-            interactive         => { default => 1 },
-            noisy               => { default => 1 },
-            max_count           => { default => 0 },
-        };
-        
-        return $self->{default_options};
-    }
-
-    # So to add a "questions" option that's mandatory:
-
-    sub default_options {
-        super;
-        $self->{default_options}->{questions}=1;
-        return $self->{default_options};
-    }
-
-=cut
-
-sub default_options {
-
-    $self->{default_options} = {
-        friend_ids          => 0,
-        cache_file          => 0,
-        html                => 0,
-        browser             => 0,
-        exclude_my_friends  => { default => 0 },
-        interactive         => { default => 1 },
-        noisy               => { default => 1 },
-        max_count           => { default => 0 },
-    };
-    
-    return $self->{default_options};
-}
+};
 
 
 =head2 friend_ids
@@ -925,7 +888,7 @@ your bug as I make changes.
 
 You can find documentation for this module with the perldoc command.
 
-    perldoc WWW::Sitebase::Poster
+    perldoc WWW::SiteBase::Poster
 
 You can also look for information at:
 
